class SwipeCollectionViewController < UICollectionViewController

  CELL_ID = 'CellID'

  attr_accessor :delegate
  attr_accessor :selectedIndex

  def initWithFrame frame
    initWithCollectionViewLayout SwipeTitleLayout.new

    collectionView.frame = CGRectMake(frame.origin.x,
      frame.origin.y,
      frame.size.width,
      frame.size.height)

    self
  end

  def initWithCollectionViewLayout layout
    super

    collectionView.backgroundColor = UIColor.clearColor
    collectionView.showsHorizontalScrollIndicator = false
    
    selectedIndex = 0

    @layout = layout
    @layout.delegate = self

    @titles = []

    collectionView.registerClass TitlePage,
      forCellWithReuseIdentifier: CELL_ID

    self
  end

  def titles= titles
    @titles = titles
    reloadData
  end

  def scrollToItemAtIndex index
    return if index > @titles.length - 1
    
    self.selectedIndex = index

    p = CGPointMake(@layout.centerOfElementAtIndex(index), 0)
    collectionView.setContentOffset p, animated: true
  end

  def selectedIndex= index
    delegate.swipeTitleControllerSelectedIndex(self, index)
  end

  def reloadData
    collectionView.reloadData
  end

  def collectionView view, numberOfItemsInSection: section
    @titles.length
  end
  
  def didSelectRowAtIndex index
    delegate.didSelectRowAtIndex index if delegate.responds_to?(:didSelectRowAtIndex)
  end

  def collectionView view, cellForItemAtIndexPath: indexPath
    view.dequeueReusableCellWithReuseIdentifier(CELL_ID,
      forIndexPath: indexPath).tap do |c|
      c.titleLabel.text         = @titles[indexPath.row]
      c.titleLabel.color        = UIColor.whiteColor
      
      c.titleLabel.shadowOffset = [1, 1]
    end
  end

  def scrollViewWillBeginDragging scrollView
    delegate.swipeBegan
  end

  def scrollViewWillEndDragging scrollView,
    withVelocity: velocity,
    targetContentOffset: targetContentOffset
    delegate.swipeEnded
  end

  def scrollViewDidScroll scrollView
    offset = scrollView.contentOffset

    offset.x = 0 if offset.x < 0
    offset.x = scrollView.contentSize.width - scrollView.frame.size.width if offset.x + scrollView.frame.size.width > scrollView.contentSize.width

    scrollView.contentOffset = offset
  end

end