class SwipeTitleController < UIViewController

  CELL_ID = 'CellID'

  attr_accessor :delegate
  attr_accessor :selectedIndex

  def viewDidLoad
    view.layer.tap do |l|
      l.masksToBounds = false
      l.cornerRadius  = 5
      l.shadowOffset  = CGSizeMake(0, 0)
      l.shadowRadius  = 8
      l.shadowOpacity = 0
    end

    @swipeController = SwipeCollectionViewController.alloc.initWithFrame(CGRectZero)
    @swipeController.delegate = self
    view.addSubview @swipeController.collectionView

    @pageControl = UIPageControl.alloc.initWithFrame(CGRectZero)
    @pageControl.userInteractionEnabled = false
    view.addSubview @pageControl
  end

  def viewWillLayoutSubviews
    @swipeController.collectionView.frame = CGRectMake(0, 0,
      view.frame.size.width, view.frame.size.height)
    @pageControl.frame = CGRectMake(0, view.frame.size.height - 14,
      view.frame.size.width, 14)
  end

  def scrollToItemAtIndex index
    @swipeController.scrollToItemAtIndex index
    @pageControl.currentPage = index
  end

  def swipeTitleControllerSelectedIndex controller, index
    @pageControl.currentPage = index
    delegate.swipeTitleControllerSelectedIndex controller, index
  end

  def titles= titles
    @pageControl.numberOfPages = titles.length

    @pageControl.hidden = titles.length == 1

    @swipeController.titles = titles
    @swipeController.reloadData
  end

  # Called by Swipe Collection View Controller

  def swipeBegan
    view.layer.shadowOpacity = 1
  end

  def swipeEnded
    UIView.transitionWithView view,
      duration: 0.1,
      options: UIViewAnimationOptionTransitionCrossDissolve,
      animations: -> {
        view.layer.shadowOpacity = 0
      },
    completion:nil
  end

end