class SwipeTitleLayout < UICollectionViewLayout

  attr_accessor :delegate

  def rows
    @rows
  end

  def init
    super
    @centerPostions = {}
    self
  end

  def shouldInvalidateLayoutForBoundsChange oldBounds
    true
  end

  def prepareLayout
    super
    
    @titles = if collectionView.numberOfSections > 0
      collectionView.numberOfItemsInSection 0
    else
      0
    end
  end

  def collectionViewContentSize
    width = @titles * collectionView.frame.size.width
    size = CGSizeMake(width, collectionView.frame.size.height)
    collectionView.contentSize = size
    size
  end

  def layoutAttributesForElementsInRect rect
    objs = []
    @titles.times do |t|
      indexPath = NSIndexPath.indexPathForItem(t, inSection:0)
      objs << layoutAttributesForItemAtIndexPath(indexPath)
    end

    objs
  end

  def scrollViewDidScroll pos
    index = selectElementAtPosition pos
  end

  def layoutAttributesForItemAtIndexPath path
    UICollectionViewLayoutAttributes.
      layoutAttributesForCellWithIndexPath(path).tap do |obj|

      x = (path.row + 0.5) * collectionView.frame.size.width
      y = (collectionView.frame.size.height - 14) / 2

      obj.center = [x, y]
      obj.size = [collectionView.frame.size.width, collectionView.frame.size.height - 14]
    end
  end

  def targetContentOffsetForProposedContentOffset proposedOffset,
    withScrollingVelocity: velocity
    offset = proposedOffset
    index = selectElementAtPosition proposedOffset.x

    offset.x = centerOfElementAtIndex index

    offset

    proposedOffset
  end

  def centerOfElementAtIndex index
    unless @centerPostions.has_key? index
      pos = index * collectionView.frame.size.width
      @centerPostions[index] = pos
    end

    @centerPostions[index]
  end

  private

  def centerOfPage? pos
    @centerPostions.has_value? pos.round
  end

  def selectElementAtPosition pos
    index = indexOfElementAtPosition pos

    if index != delegate.selectedIndex
      delegate.selectedIndex = index
    end

    index
  end

  def indexOfElementAtPosition position
    (position / collectionView.frame.size.width).round
  end

end